@@ -3,7 +3,7 @@
 # Copyright (C) 2006-2011 Leigh L. Klotz, Jr <Leigh@WA5ZNU.org>
 # Licensed under Academic Free License 3.0 (See LICENSE)
 
-import string, serial, time, sys, math, os
+import string, serial, time, os
 from lxml import etree
 
 CONFIGFILE = "~/.rigcontrol/k3.xml"
@@ -33,7 +33,6 @@ class K3:
   def read(self,n):
     return self.ser.read(n)
 
-
   #
   # Set the VFO current frequency
   # FA00014060000
@@ -94,7 +93,7 @@ class K3:
   #
   # Set NB to level (off=0, 1, 2)
   # TODO: use SW22; to change thresh but we have to ready it first
-  def nb(level, thresh):
+  def nb(self, level, thresh):
     self.write("NB%s;" % (level))
 
   #
@@ -169,7 +168,7 @@ class K3:
     return self.paq()
 
   #
-  # Get the PA
+  # Get the preamp
   def paq(self):
     self.write("PA;");
     result = self.read(4);
@@ -180,6 +179,24 @@ class K3:
     else:
         return "off"
 
+  #
+  # Set the power output
+  # PC000; off
+  # PC010; 10 watts
+  def power(self,watts):
+    cmd = "PC%03d;" % (watts)
+    self.write(cmd)
+    return self.powerq()
+
+  #
+  # Get the power output
+  def powerq(self):
+    self.write("PC;");
+    result = self.read(6);
+    if (len(result) <> 6):
+      return 0
+    return int(result[2:5])
+
   #
   # Set to VFO A for TX and RX
   def vfoa(self):
@@ -276,7 +293,7 @@ class K3:
       return 0
     return result[2:6] + "Hz " + result[7]
 
-
+  #
   # Get the display
   def displayq(self):
     self.write("DS;");
@@ -295,7 +312,7 @@ class K3:
   # -> RV*nn.nn;
   def verq(self,x):
     self.write("RV%c;" % (x))
-    result = selfread(9);
+    result = self.read(9);
     if (len(result) <> 9):
       return 0
     ver = result[3:8]
@@ -382,4 +399,3 @@ class K3:
       k3hour = k3hour - 1
     self.write("MN255;")        # exit menu
     return self.timeq()
-
